@@ -33,7 +33,7 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /****************************************************************
  *
- * initx.h:  HyperDoc X Window window initialization code
+ * initx.c:  HyperDoc X Window window initialization code
  *
  * Copyright The Numerical Algorithms Group Limited 1991, 1992, 1993.
  *
@@ -41,11 +41,9 @@ SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 
 /* #define DEBUG  1 */
 
-#include "axiom-c-macros.h"
+#include "fricas_c_macros.h"
 #include "debug.h"
 
-#include "initx.h"
-
 #include <unistd.h>
 #include <sys/signal.h>
 #include <setjmp.h>
@@ -59,10 +57,7 @@ extern int gethostname(char *, int );
 
 #include "ht_icon"
 #include "extent.h"
-#include "group.h"
-#include "mem.h"
-#include "scrollbar.h"
-#include "titlebar.h"
+#include "hyper.h"
 
 #include "all_hyper_proto.H1"
 #include "util.H1"
@@ -96,7 +91,7 @@ extern int gTtFontIs850;
 
 
 int gActiveColor,
-    gAxiomColor,
+    fricas_color,
     gBackgroundColor,
     gBfColor,
     gControlBackgroundColor,
@@ -109,7 +104,7 @@ int gActiveColor,
     gSlColor,
     gTtColor;
 
-XFontStruct *gAxiomFont,
+XFontStruct * fricas_font,
             *gActiveFont,
             *gBfFont,
             *gEmFont,
@@ -173,11 +168,12 @@ initializeWindowSystem(void)
 /*  fprintf(stderr,"initx:initializeWindowSystem:XCreateBitmapFromData 1\n");*/
     mousebits = XCreateBitmapFromData(gXDisplay,
         RootWindow(gXDisplay, gXScreenNumber),
-        mouseBitmap_bits, mouseBitmap_width,mouseBitmap_height);
+        ucharp_to_charp(mouseBitmap_bits),
+        mouseBitmap_width,mouseBitmap_height);
 /* fprintf(stderr,"initx:initializeWindowSystem:XCreateBitmapFromData 2\n");*/
     mousemask = XCreateBitmapFromData(gXDisplay,
         RootWindow(gXDisplay, gXScreenNumber),
-        mouseMask_bits, mouseMask_width,mouseMask_height);
+        ucharp_to_charp(mouseMask_bits), mouseMask_width,mouseMask_height);
 /* fprintf(stderr,"initx:initializeWindowSystem:XCreateBitmapFromData 2\n");*/
     gActiveCursor = XCreatePixmapCursor(gXDisplay,
         mousebits, mousemask, &fg, &bg,
@@ -281,8 +277,8 @@ open_form_window(void)
     char userdefaults[50], progdefaults[50];
 
     strcpy(progdefaults, "=950x450+0+0");
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.FormGeometry",
-        "Axiom.hyperdoc.FormGeometry", str_type, &value) == True)
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.FormGeometry",
+        "FriCAS.hyperdoc.FormGeometry", str_type, &value) == True)
     {
         strncpy(userdefaults, value.addr, (int) value.size);
         userSpecified = 1;
@@ -393,7 +389,8 @@ set_name_and_icon(void)
     XStoreName(gXDisplay, gWindow->fMainWindow, "HyperDoc");
 
     /* define and assign the pixmap for the icon */
-    icon_pixmap = XCreateBitmapFromData(gXDisplay, gWindow->fMainWindow, ht_icon_bits,
+    icon_pixmap = XCreateBitmapFromData(gXDisplay, gWindow->fMainWindow,
+                                        ucharp_to_charp(ht_icon_bits),
                                         ht_icon_width, ht_icon_height);
     wmhints.icon_pixmap = icon_pixmap;
     wmhints.flags = IconPixmapHint;
@@ -415,7 +412,7 @@ get_border_properties(void)
     /*int ret_val;*/
 
 
-    bwidth = "2";  /* XGetDefault(gXDisplay, "Axiom.hyperdoc", "BorderWidth") */
+    bwidth = "2";  /* XGetDefault(gXDisplay, "FriCAS.hyperdoc", "BorderWidth") */
 
     if (bwidth == NULL)
         bw = 1;
@@ -423,7 +420,8 @@ get_border_properties(void)
         bw = atoi(bwidth);
         if (bw < 1) {
             fprintf(stderr,
-                    "%s: The line width value must be greater than zero\n", "Axiom.hyperdoc");
+                    "%s: The line width value must be greater than zero\n",
+                    "FriCAS.hyperdoc");
             bw = 1;
         }
     }
@@ -458,8 +456,8 @@ open_window(Window w)
     char userdefaults[50], progdefaults[50];
 
     strcpy(progdefaults, "=700x450+0+0");
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.Geometry",
-        "Axiom.hyperdoc.Geometry", str_type, &value) == True)
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.Geometry",
+        "FriCAS.hyperdoc.Geometry", str_type, &value) == True)
     {
         strncpy(userdefaults, value.addr, (int) value.size);
     }
@@ -496,7 +494,7 @@ open_window(Window w)
 }
 
 /***
-  This routine gets and sets the size for a new window. If the w paramter
+  This routine gets and sets the size for a new window. If the w parameter
   is null, it means that this is the initial window. Thus the user
   preferences are checked. If this is not the first window, then the
   window w is used as a guidline, and the new window is placed on top of
@@ -552,14 +550,14 @@ set_size_hints(Window w)
     else {
         /* this is the first window, so lets try to find a nice spot for it */
 
-        if (XrmGetResource(rDB, "Axiom.hyperdoc.Geometry", "Axiom.hyperdoc.Geometry",
-            str_type, &value) == True)
-        {
+        if (XrmGetResource(rDB, "FriCAS.hyperdoc.Geometry",
+                           "FriCAS.hyperdoc.Geometry", str_type,
+                           &value) == True) {
             strncpy(userdefaults, value.addr, (int) value.size);
             geo = XParseGeometry(userdefaults, &x, &y, &width, &height);
-        }
-        else
+        } else {
             strcpy(userdefaults, progdefaults);
+        }
 
         size_hints.flags |= (geo & (WidthValue | HeightValue)) ? USSize : PSize;
         size_hints.flags |= (geo & (XValue | YValue)) ? USPosition : PPosition;
@@ -663,15 +661,15 @@ load_font(XFontStruct **font_info, char *fontname)
  * This routine initializes all the colors and fonts that the user wishes to
  * use. It checks for all the following properties in $HOME/.Xdefaults.
  *
- *  Axiom.hyperdoc.ActiveColor:
- *  Axiom.hyperdoc.Background:
- *  Axiom.hyperdoc.EmphasizeColor:
- *  Axiom.hyperdoc.EmphasizeFont:
- *  Axiom.hyperdoc.Foreground:
- *  Axiom.hyperdoc.InputBackground:
- *  Axiom.hyperdoc.InputForeground:
- *  Axiom.hyperdoc.SpadColor:
- *  Axiom.hyperdoc.SpadFont:
+ *  FriCAS.hyperdoc.ActiveColor:
+ *  FriCAS.hyperdoc.Background:
+ *  FriCAS.hyperdoc.EmphasizeColor:
+ *  FriCAS.hyperdoc.EmphasizeFont:
+ *  FriCAS.hyperdoc.Foreground:
+ *  FriCAS.hyperdoc.InputBackground:
+ *  FriCAS.hyperdoc.InputForeground:
+ *  FriCAS.hyperdoc.SpadColor:
+ *  FriCAS.hyperdoc.SpadFont:
  */
 
 static void
@@ -700,11 +698,12 @@ ingItColors_and_fonts(void)
     mergeDatabases();
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:XrmGetResource\n");*/
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.RmFont",
-                            "Axiom.hyperdoc.Font", str_type, &value) == True)
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.RmFont",
+                       "FriCAS.hyperdoc.Font", str_type, &value) == True) {
         (void) strncpy(prop, value.addr, (int) value.size);
-    else
+    } else {
         (void) strcpy(prop, RmFontDefault);
+    }
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:load_font 1\n");*/
     load_font(&gRmFont, prop);
@@ -713,66 +712,60 @@ ingItColors_and_fonts(void)
 
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:XrmGetResource 2\n");*/
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.TtFont",
-                            "Axiom.hyperdoc.Font", str_type, &value) == True)
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.TtFont",
+                       "FriCAS.hyperdoc.Font", str_type, &value) == True) {
         (void) strncpy(prop, value.addr, (int) value.size);
-    else
+    } else {
         (void) strcpy(prop, TtFontDefault);
-
+    }
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:load_font 3\n");*/
     load_font(&gTtFont, prop);
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:is_it_850\n");*/
     gTtFontIs850=is_it_850(gTtFont);
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:XrmGetResource 5\n");*/
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.ActiveFont",
-                            "Axiom.hyperdoc.Font", str_type, &value) == True)
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.ActiveFont",
+                       "FriCAS.hyperdoc.Font", str_type, &value) == True) {
         (void) strncpy(prop, value.addr, (int) value.size);
-    else
+    } else {
         (void) strcpy(prop, ActiveFontDefault);
-
+    }
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:load_font 4\n");*/
     load_font(&gActiveFont, prop);
 
     /* maintain backwards compatibility */
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:XrmGetResource 6\n");*/
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.AxiomFont",
-                            "Axiom.hyperdoc.Font", str_type, &value) == True)
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.FriCASFont",
+                       "FriCAS.hyperdoc.Font", str_type, &value) == True) {
         (void) strncpy(prop, value.addr, (int) value.size);
-    else {
-        if (XrmGetResource(rDB, "Axiom.hyperdoc.SpadFont",
-                           "Axiom.hyperdoc.Font", str_type, &value) == True)
-        {
+    } else {
+        if (XrmGetResource(rDB, "FriCAS.hyperdoc.SpadFont",
+                        "FriCAS.hyperdoc.Font", str_type, &value) == True) {
             (void) strncpy(prop, value.addr, (int) value.size);
-        }
-        else {
-            (void) strcpy(prop, AxiomFontDefault);
+        } else {
+            (void) strcpy(prop, fricas_font_default);
         }
     }
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:load_font 5\n");*/
-    load_font(&gAxiomFont, prop);
+    load_font(&fricas_font, prop);
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:XrmGetResource 7\n");*/
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.EmphasizeFont",
-                            "Axiom.hyperdoc.Font", str_type, &value) == True)
-    {
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.EmphasizeFont",
+                       "FriCAS.hyperdoc.Font", str_type, &value) == True) {
         (void) strncpy(prop, value.addr, (int) value.size);
-    }
-    else {
+    } else {
         (void) strcpy(prop, EmphasizeFontDefault);
     }
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:load_font 6\n");*/
     load_font(&gEmFont, prop);
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:XrmGetResource 8\n");*/
-    if (XrmGetResource(rDB, "Axiom.hyperdoc.BoldFont",
-                            "Axiom.hyperdoc.Font", str_type, &value) == True)
-    {
+    if (XrmGetResource(rDB, "FriCAS.hyperdoc.BoldFont",
+                       "FriCAS.hyperdoc.Font", str_type, &value) == True) {
         (void) strncpy(prop, value.addr, (int) value.size);
-    }
-    else {
+    } else {
         (void) strcpy(prop, BoldFontDefault);
     }
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:load_font 7\n");*/
@@ -786,7 +779,7 @@ ingItColors_and_fonts(void)
 
 /*    fprintf(stderr,"initx:ingItColors_and_fonts:DisplayPlanes\n");*/
     if (DisplayPlanes(gXDisplay, gXScreenNumber) == 1) {
-        gActiveColor       = gAxiomColor
+        gActiveColor       = fricas_color
                             = gControlBackgroundColor
                             = gInputBackgroundColor
                             = gBfColor
@@ -835,10 +828,10 @@ ingItColors_and_fonts(void)
         /* maintain backwards compatibility */
 
 /*        fprintf(stderr,"initx:ingItColors_and_fonts:get_color 6\n");*/
-        gAxiomColor = get_color("AxiomColor", "Foreground", 0, &cmap);
+        fricas_color = get_color("FriCASColor", "Foreground", 0, &cmap);
 /*        fprintf(stderr,"initx:ingItColors_and_fonts:get_color 7\n");*/
-        if (gAxiomColor == 0)
-            gAxiomColor = get_color("SpadColor", "Foreground",
+        if (fricas_color == 0)
+            fricas_color = get_color("SpadColor", "Foreground",
                 BlackPixel(gXDisplay, gXScreenNumber), &cmap);
 
 /*        fprintf(stderr,"initx:ingItColors_and_fonts:get_color 8\n");*/
@@ -911,10 +904,10 @@ get_color(char *name, char *class, int def, Colormap *map)
     printf("get_color: %s %s %d -> ", name, class, def);
 #endif
 
-    strcpy(fullname, "Axiom.hyperdoc.");
+    strcpy(fullname, "FriCAS.hyperdoc.");
     strcat(fullname, name);
-    strcpy(fullclass,"Axiom.hyperdoc.");
-    strcat(fullclass,class);
+    strcpy(fullclass, "FriCAS.hyperdoc.");
+    strcat(fullclass, class);
 
     if (XrmGetResource(rDB, fullname, fullclass, str_type, &value) == True) {
         (void) strncpy(prop, value.addr, (int) value.size);
@@ -950,7 +943,7 @@ mergeDatabases(void)
     XrmDatabase homeDB, serverDB, applicationDB;
     char filenamebuf[1024];
     char *filename = &filenamebuf[0];
-    char *classname = "Axiom";
+    char *classname = "FriCAS";
     char name[255];
 
 /*    fprintf(stderr,"initx:mergeDatabases:entered\n");*/
@@ -1019,4 +1012,3 @@ is_it_850(XFontStruct *fontarg)
   }
  return(0);
 }
-
