@@ -53,7 +53,7 @@
 (defmacro def-boot-val (p val where) `(defparameter ,p ,val ,where))
 
 (def-boot-val |$timerTicksPerSecond| INTERNAL-TIME-UNITS-PER-SECOND
-    "for TEMPUS-FUGIT and $TOTAL-ELAPSED-TIME")
+    "scale for get_run_time")
 (def-boot-val $boxString
   (concatenate 'string (list (code-char #x1d) (code-char #xe2)))
   "this string of 2 chars displays as a box")
@@ -96,20 +96,14 @@
 (def-boot-var |$mathTrace|                          "Interpreter>Trace.boot")
 (def-boot-var |$mathTraceList|              "Controls mathprint output for )trace.")
 
-(def-boot-val |$oldTime| 0                          "???")
-
 (def-boot-var |$postStack|                          "???")
 (def-boot-var |$previousTime|                       "???")
-(def-boot-val |$printLoadMsgs|  '|off|          "Interpreter>SetVarT.boot")
-(def-boot-var |$PrintOnly|                          "Compiler>LispLib.boot")
+(def-boot-val |$printLoadMsgs|  nil          "Interpreter>SetVarT.boot")
 (def-boot-var |$reportBottomUpFlag|                 "Interpreter>SetVarT.boot")
 (def-boot-var |$returnMode|                         "???")
 (def-boot-var |$semanticErrorStack|                 "???")
 (def-boot-val |$SetFunctions| nil  "checked in SetFunctionSlots")
 
-(def-boot-val $SPAD nil                             "Is this Spad code?")
-
-(def-boot-val |$timerOn| t                          "???")
 (def-boot-var |$topOp|                             "See displayPreCompilationErrors")
 (def-boot-var |$tracedSpadModemap|                  "Interpreter>Trace.boot")
 (def-boot-var |$traceletFunctions|                  "???")
@@ -122,22 +116,8 @@
 
 ; End of moved fragment
 
-(defvar |$compilingMap| ())
-(defvar |$definingMap| nil)
-
 ; 5 PROGRAM STRUCTURE
 
-; 5.3 Top-Level Forms
-
-
-(defun SETANDFILE (x y) (LAM\,EVALANDFILEACTQ `(defparameter ,x ',y)))
-
-(defun LAM\,EVALANDFILEACTQ (name &optional (form name))
-    (|outputLispForm| name form) (eval form))
-
-(defun |outputLispForm| (name form)
-       (if *FILEACTQ-APPLY* (FUNCALL *FILEACTQ-APPLY* name form)))
-
 ; 5.3.2 Declaring Global Variables and Named Constants
 
 (defun |functionp| (fn)
@@ -334,101 +314,8 @@
   "Evaluates an object and returns it with QUOTE wrapped around it."
   (if (NUMBERP X) X (LIST 'QUOTE X)))
 
-; 7.8 Iteration
-
-; 7.8.2 General Iteration
-
-(DEFUN MKPF (L OP)
-  (if (FLAGP OP 'NARY) (SETQ L (MKPFFLATTEN-1 L OP NIL)))
-  (MKPF1 L OP))
-
-(DEFUN MKPFFLATTEN (X OP)
-  (COND ((ATOM X) X)
-        ((EQL (CAR X) OP) (CONS OP (MKPFFLATTEN-1 (CDR X) OP NIL)))
-        ((CONS (MKPFFLATTEN (CAR X) OP) (MKPFFLATTEN (CDR X) OP)))))
-
-(DEFUN MKPFFLATTEN-1 (L OP R)
-  (let (X)
-    (if (NULL L)
-        R
-        (MKPFFLATTEN-1 (CDR L) OP
-           (APPEND R (if (EQCAR (SETQ X
-                                      (MKPFFLATTEN (CAR L) OP)) OP)
-                         (CDR X) (LIST X)))))))
-
-(DEFUN MKPF1 (L OP)
-  (let (X) (case OP (PLUS (COND ((EQL 0 (SETQ X (LENGTH
-                                                 (SETQ L (S- L '(0 (ZERO))))))) 0)
-                                ((EQL 1 X) (CAR L))
-                                ((CONS 'PLUS L)) ))
-                 (TIMES (COND ((S* L '(0 (ZERO))) 0)
-                              ((EQL 0 (SETQ X (LENGTH
-                                               (SETQ L (S- L '(1 (ONE))))))) 1)
-                              ((EQL 1 X) (CAR L))
-                              ((CONS 'TIMES L)) ))
-                 (QUOTIENT (COND ((> (LENGTH L)) (fail))
-                                 ((EQL 0 (CAR L)) 0)
-                                 ((EQL (CADR L) 1) (CAR L))
-                                 ((CONS 'QUOTIENT L)) ))
-                 (MINUS (COND ((CDR L) (FAIL))
-                              ((NUMBERP (SETQ X (CAR L))) (- X))
-                              ((EQCAR X 'MINUS) (CADR X))
-                              ((CONS 'MINUS L))  ))
-                 (DIFFERENCE (BREAK))
-                 (EXPT (COND ((> (LENGTH L) 2) (FAIL))
-                             ((EQL 0 (CADR L)) 1)
-                             ((EQL 1 (CADR L)) (CAR L))
-                             ((|member| (CAR L) '(0 1 (ZERO) (ONE))) (CAR L))
-                             ((CONS 'EXPT L)) ))
-                 (OR (COND ((MEMBER 'T L) ''T)
-                           ((EQL 0 (SETQ X (LENGTH (SETQ L (REMOVE NIL L))))) NIL)
-                           ((EQL 1 X) (CAR L))
-                           ((CONS 'OR L)) ))
-                 (|or| (COND ((MEMBER 'T L) 'T)
-                             ((EQL 0 (SETQ X (LENGTH (SETQ L (REMOVE NIL L))))) NIL)
-                             ((EQL 1 X) (CAR L))
-                             ((CONS 'or L)) ))
-                 (NULL (COND ((CDR L) (FAIL))
-                             ((EQCAR (CAR L) 'NULL) (CADAR L))
-                             ((EQL (CAR L) 'T) NIL)
-                             ((NULL (CAR L)) ''T)
-                             ((CONS 'NULL L)) ))
-                 (|and| (COND ((EQL 0 (SETQ X (LENGTH
-                                               (SETQ L (REMOVE T (REMOVE '|true| L)))))) T)
-                              ((EQL 1 X) (CAR L))
-                              ((CONS '|and| L)) ))
-                 (AND (COND ((EQL 0 (SETQ X (LENGTH
-                                             (SETQ L (REMOVE T (REMOVE '|true| L)))))) ''T)
-                            ((EQL 1 X) (CAR L))
-                            ((CONS 'AND L)) ))
-                 (PROGN (COND ((AND (NOT (ATOM L)) (NULL (LAST L)))
-                               (if (CDR L) `(PROGN . ,L) (CAR L)))
-                              ((NULL (SETQ L (REMOVE NIL L))) NIL)
-                              ((CDR L) (CONS 'PROGN L))
-                              ((CAR L))))
-                 (SEQ (COND ((EQCAR (CAR L) 'EXIT) (CADAR L))
-                            ((CDR L) (CONS 'SEQ L))
-                            ((CAR L))))
-                 (LIST (if L (cons 'LIST L)))
-                 (CONS (if (cdr L) (cons 'CONS L) (car L)))
-                 (t (CONS OP L) ))))
-
 (defvar $TRACELETFLAG NIL "Also referred to in Comp.Lisp")
 
-(defvar $BOOT NIL)
-
-; 10.1 The Property List
-
-(DEFUN FLAG (L KEY)
-  "Set the KEY property of every item in list L to T."
-  (mapc #'(lambda (item) (makeprop item KEY T)) L))
-
-(FLAG '(* + AND OR PROGN) 'NARY)                ; flag for MKPF
-
-(DEFUN FLAGP (X KEY)
-  "If X has a KEY property, then FLAGP is true."
-  (GET X KEY))
-
 ; 10.3 Creating Symbols
 
 (defun INTERNL(a &rest b)
@@ -447,13 +334,6 @@
 
 ; 14.2 Concatenating, Mapping, and Reducing Sequences
 
-(MAPC #'(LAMBDA (X) (MAKEPROP (CAR X) 'THETA (CDR X)))
-      '((PLUS 0) (+ (|Zero|)) (|lcm| (|One|)) (STRCONC "") (|strconc| "")
-        (MAX -999999) (MIN 999999) (TIMES 1) (* (|One|)) (CONS NIL)
-        (APPEND NIL) (|append| NIL) (UNION NIL) (UNIONQ NIL) (|gcd| (|Zero|))
-        (|union| NIL) (NCONC NIL) (|and| |true|) (|or| |false|) (AND 'T)
-        (OR NIL)))
-
 (defun |delete| (item sequence)
    (cond ((symbolp item) (remove item sequence :test #'eq))
          ((and (atom item) (not (arrayp item))) (remove item sequence))
@@ -489,14 +369,6 @@
         ((>= (setq m (+ (length x) N)) 0) (DROP m x))
         ((CROAK (list "Bad args to DROP" N X)))))
 
-(DEFUN TRUNCLIST (L TL) "Truncate list L at the point marked by TL."
-  (let ((U L)) (TRUNCLIST-1 L TL) U))
-
-(DEFUN TRUNCLIST-1 (L TL)
-  (COND ((ATOM L) L)
-        ((EQL (CDR L) TL) (RPLACD L NIL))
-        ((TRUNCLIST-1 (CDR L) TL))))
-
 ; 15.4 Substitution of Expressions
 
 ;; needed for substNames (always copy)
@@ -515,13 +387,12 @@
         (SETQ FORM (CDR FORM))
         (GO LP)))
 
-(DEFUN SUBLISNQ (KEY E) (declare (special KEY)) (if (NULL KEY) E (SUBANQ E)))
+(DEFUN SUBLISNQ (KEY E) (if (NULL KEY) E (SUBANQ KEY E)))
 
-(DEFUN SUBANQ (E)
-  (declare (special key))
+(DEFUN SUBANQ (KEY E)
   (COND ((ATOM E) (SUBB KEY E))
         ((EQCAR E (QUOTE QUOTE)) E)
-        ((MAPCAR #'(LAMBDA (J) (SUBANQ J)) E))))
+        ((MAPCAR #'(LAMBDA (J) (SUBANQ KEY J)) E))))
 
 (DEFUN SUBB (X E)
   (COND ((ATOM X) E)
@@ -560,7 +431,6 @@
         ((MEMBER (CAR X) Y :test #'equal) (S+ (CDR X) Y))
         ((S+ (CDR X) (CONS (CAR X) Y)))))
 
-(defun S* (l1 l2) (INTERSECTION l1 l2 :test #'equal))
 (defun S- (l1 l2) (set-difference l1 l2 :test #'equal))
 
 (DEFUN PREDECESSOR (TL L)
@@ -729,7 +599,7 @@
 
 (defun print-and-eval-defun (name body)
    (eval body)
-   (print-defun name body)
+   (|print_defun| name body)
    )
 
 (defun eval-defun (name body) (eval (macroexpandall body)))
@@ -793,18 +663,16 @@
 (defun |make_BF| (MT EP) (LIST |$BFtag| MT EP))
 
 (defun |make_float| (int frac fraclen exp)
-    (if (AND $SPAD |$useBFasDefault|)
-        (if (= frac 0)
+    (if (= frac 0)
           (|make_BF| int exp)
-          (|make_BF| (+ (* int (expt 10 fraclen)) frac) (- exp fraclen)) )
-        (read-from-string
-          (format nil "~D.~v,'0De~D" int fraclen frac exp))) )
+          (|make_BF| (+ (* int (expt 10 fraclen)) frac) (- exp fraclen)) ))
 
-(defun print-full (expr &optional (stream *standard-output*))
+(defun |print_full2| (expr stream)
    (let ((*print-circle* t) (*print-array* t) *print-level* *print-length*)
      (print expr stream)
-     (terpri stream)
-     (finish-output stream)))
+     (terpri stream)))
+
+(defun |print_full1| (expr) (|print_full2| expr *standard-output*))
 
 ;; moved here from preparse.lisp
 
@@ -835,6 +703,18 @@
                   (concatenate 'string
                                (make-string tpos :initial-element #\space)
                                (subseq str bpos))))
+        (loop
+            (let ((tloc (tabloc str)))
+                (if (null tloc) (return))
+                (let ((rloc (NEXT-TAB-LOC tloc)))
+                    (if (eql tloc rloc)
+                        (setf (aref str tloc) #\Space)
+                        (setf str
+                            (concatenate 'string
+                                (subseq str 0 tloc)
+                                (make-string (+ 1 (- rloc tloc))
+                                    :initial-element #\space)
+                                (subseq str (+ 1 tloc))))))))
          ;; remove dos CR
         (let ((lpos (maxindex str)))
           (if (eq (char str lpos) #\Return) (subseq str 0 lpos) str)))
@@ -844,6 +724,10 @@
 
 (defun nonblankloc (str) (position-if-not #'blankp str))
 
+(defun tabp (c) (equal c #\tab))
+
+(defun tabloc (str) (position-if #'tabp str))
+
 ;; stream handling for paste-in generation
 
 (defun |applyWithOutputToString| (func args)
@@ -857,8 +741,7 @@
     (declare (special curoutstream
                       |$algebraOutputStream|))
     (setq val (catch 'spad_reader
-                (catch 'TOP_LEVEL
-                  (apply (symbol-function func) args))))
+                  (apply (symbol-function func) args)))
     (cons val (get-output-stream-string *standard-output*))))
 
 (defun |breakIntoLines| (str)
@@ -884,7 +767,7 @@
   (let ((|$comp370_apply|
          (if |$InteractiveMode|
              (if |$compileDontDefineFunctions| #'compile-defun #'eval-defun)
-           #'print-defun))
+           #'|print_defun|))
      ;; following creates a null outputstream if $InteractiveMode
         (*standard-output*
          (if |$InteractiveMode| (make-broadcast-stream)
@@ -914,3 +797,58 @@
 
 ; end of moved fragment
 
+;;; moved from debug.lisp
+
+; NAME:    Debugging Package
+; PURPOSE: Debugging hooks for Boot code
+
+(defun enable-backtrace (&rest arg))
+
+(defun |adjoin_equal|(x y) (ADJOIN x y :test #'equal))
+
+(defun |remove_equal|(x y) (REMOVE x y :test #'equal))
+
+(defun WHOCALLED(n) nil) ;; no way to look n frames up the stack
+
+(defun heapelapsed () 0)
+
+(defun |goGetTracerHelper| (dn f oname alias options modemap)
+    (lambda(&rest l)
+         (|goGetTracer| l dn f oname alias options modemap)))
+
+(defun |setSf| (sym fn) (SETF (SYMBOL-FUNCTION sym) fn))
+
+(DEFUN IS_SHARP_VAR (X)
+  (AND (IDENTP X)
+       (EQL (ELT (PNAME X) 0) #\#)
+       (INTEGERP (parse-integer (symbol-name X) :start 1))))
+
+(defun |char_to_digit|(x) (digit-char-p x))
+
+(defun SPADSYSNAMEP (STR)
+  (let (n i j)
+    (AND (SETQ N (MAXINDEX STR))
+         (SETQ I (position #\. STR :start 1))
+         (SETQ J (position #\, STR :start (1+ I)))
+         (do ((k (1+ j) (1+ k)))
+             ((> k n) t)
+           (if (not (digitp (elt str k))) (return nil))))))
+
+; **********************************************************************
+;            Utility functions for Tracing Package
+; **********************************************************************
+
+(MAKEPROP '|coerce| '/TRANSFORM '(& & *))
+(MAKEPROP '|comp| '/TRANSFORM '(& * * &))
+(MAKEPROP '|compIf| '/TRANSFORM '(& * * &))
+
+;  by having no transform for the 3rd argument, it is simply not printed
+
+(MAKEPROP '|compFormWithModemap| '/TRANSFORM '(& * * & *))
+
+;;; A "resumable" break loop for use in trace etc. Unfortunately this
+;;; only worked for CCL. We need to define a Common Lisp version. For
+;;; now the function is defined but does nothing.
+(defun interrupt (&rest ignore))
+
+;;; end of moved fragment
