@@ -73,9 +73,7 @@ o  there is some code at the end of SPECEVAL BOOT that puts "up"
    (JOIN " JOIN ")
    (EQUATNUM "  ")
    (IQUOTIENT "//")
-;;   (= "=")
-   (= "= ")
-;;   (= " = ")
+   (= " = ")
    (|>=| " >= ")
    (|>| " > ")
    (|<=| " <= ")
@@ -281,7 +279,7 @@ o  there is some code at the end of SPECEVAL BOOT that puts "up"
   (|NegativeInteger| . (|<| * 0))
   ))
 
-(FLAG '(TENSOR * + AND OR PROGN) 'NARY)
+(DOLIST (X '(TENSOR * + AND OR PROGN)) (MAKEPROP X 'NARY T))
 
 (DOLIST (X '(
   (|Record| |mkRecordFunList|)
@@ -291,9 +289,6 @@ o  there is some code at the end of SPECEVAL BOOT that puts "up"
 )) (MAKEPROP (CAR X) '|makeFunctionList| (CADR X)))
 
 (DOLIST (X '(
-  (\: |parseColon|)
-  (|::| |parseCoerce|)
-  (@ |parseAtSign|)
 
   (|and| |parseAnd|)
   (CATEGORY |parseCategory|)
@@ -301,21 +296,13 @@ o  there is some code at the end of SPECEVAL BOOT that puts "up"
   (|exit| |parseExit|)
   (|has| |parseHas|)
   (IF |parseIf|)
-  (IN |parseIn|)
-  (INBY |parseInBy|)
-  (|is| |parseIs|)
-  (|isnt| |parseIsnt|)
   (|Join| |parseJoin|)
   (|leave| |parseLeave|)
-  (LET |parseLET|)
   (MDEF |parseMDEF|)
   (|not| |parseNot|)
   (|or| |parseOr|)
-  (|pretend| |parsePretend|)
-  (|return| |parseReturn|)
   (SEGMENT |parseSegment|)
   (SEQ |parseSeq|)
-  (|where| |parseWhere|)
 )) (MAKEPROP (CAR X) '|parseTran| (CADR X)))
 
 (DOLIST (X '(
